@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Rinci;
 
-our $DATE = '2015-09-25'; # DATE
-our $VERSION = '0.45'; # VERSION
+our $DATE = '2015-09-29'; # DATE
+our $VERSION = '0.46'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -56,8 +56,30 @@ sub _process_module {
     die "Can't child_metas $url: $res->[0] - $res->[1]" unless $res->[0] == 200;
     my $cmetas = $res->[2];
 
+    my $exports = {};
+    {
+        no strict 'refs';
+        my $uses_exporter_mod = @{"$package\::EXPORT"} || @{"$package\::EXPORT_OK"};
+        for my $funcname (keys %$cmetas) {
+            next unless $funcname =~ /\A\w+\z/;
+            my $funcmeta = $cmetas->{$funcname};
+            my $export = 0;
+            if ($uses_exporter_mod &&
+                    grep {$_ eq $funcname} @{"$package\::EXPORT"}) {
+                $export = 1;
+            } elsif ($uses_exporter_mod) {
+                $export = -1;
+            } elsif (grep {$_ eq 'export:default'} @{ $funcmeta->{tags} // [] }) {
+                $export = 1;
+            } elsif (grep {$_ eq 'export:never'} @{ $funcmeta->{tags} // [] }) {
+                $export = -1;
+            }
+            $exports->{$funcname} = $export;
+        }
+    }
     my $doc = Perinci::To::POD->new(
-        name=>$package, meta=>$meta, child_metas=>$cmetas, url=>$url);
+        name=>$package, meta=>$meta, child_metas=>$cmetas, url=>$url,
+        exports=>$exports);
     $doc->delete_doc_section('summary'); # already handled by other plugins
     $doc->delete_doc_section('version'); # ditto
     my $pod_text = $doc->gen_doc;
@@ -645,7 +667,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.45 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-09-25.
+This document describes version 0.46 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-09-29.
 
 =head1 SYNOPSIS
 
